justbases._constants module — justbases 0.07 documentation

### Navigation

- index
- modules |
- next |
- previous |
- justbases 0.07 documentation »
- justbases »
- justbases package »

# justbases._constants module

Constants required by the package.

class `justbases._constants.` `RoundingMethods`

  Bases: `object`

  Static class for accessing rounding methods.

  classmethod `CONDITIONAL_METHODS`()

    Conditional rounding methods.

  classmethod `METHODS`()

    Methods of this class.

  `ROUND_DOWN` = _RoundingMethod(Round down.)
  `ROUND_HALF_DOWN` = _RoundingMethod(Round to nearest, down on a tie.)
  `ROUND_HALF_UP` = _RoundingMethod(Round to nearest, up on a tie.)
  `ROUND_HALF_ZERO` = _RoundingMethod(Round to nearest, to zero on a tie.)
  `ROUND_TO_ZERO` = _RoundingMethod(Round to zero.)
  `ROUND_UP` = _RoundingMethod(Round up.)

### Navigation

- index
- modules |
- next |
- previous |
- justbases 0.07 documentation »
- justbases »
- justbases package »